@@ -36,6 +36,8 @@ pub mod file_status;
 pub use self::file_status::FileStatus;
 pub mod file_version;
 pub use self::file_version::FileVersion;
+pub mod friend_status;
+pub use self::friend_status::FriendStatus;
 pub mod inline_object;
 pub use self::inline_object::InlineObject;
 pub mod inline_object_1;
@@ -78,14 +80,16 @@ pub mod inline_response_200_5;
 pub use self::inline_response_200_5::InlineResponse2005;
 pub mod inline_response_200_6;
 pub use self::inline_response_200_6::InlineResponse2006;
-pub mod inline_response_200_7;
-pub use self::inline_response_200_7::InlineResponse2007;
-pub mod inline_response_403;
-pub use self::inline_response_403::InlineResponse403;
+pub mod inline_response_400;
+pub use self::inline_response_400::InlineResponse400;
 pub mod instance;
 pub use self::instance::Instance;
 pub mod instance_platforms;
 pub use self::instance_platforms::InstancePlatforms;
+pub mod invite_message;
+pub use self::invite_message::InviteMessage;
+pub mod invite_message_type;
+pub use self::invite_message_type::InviteMessageType;
 pub mod limited_unity_package;
 pub use self::limited_unity_package::LimitedUnityPackage;
 pub mod limited_user;
@@ -102,8 +106,6 @@ pub mod past_display_name;
 pub use self::past_display_name::PastDisplayName;
 pub mod permission;
 pub use self::permission::Permission;
-pub mod platform;
-pub use self::platform::Platform;
 pub mod player_moderation;
 pub use self::player_moderation::PlayerModeration;
 pub mod player_moderation_type;
